var target = Argument("target", "pack");
var configuration = Argument("configuration", "Release");

var toolArgs = Argument("tool-args", "--global");
var toolInstallArgs = Argument("tool-install-args", $"{toolArgs} --verbosity diagnostic");

Task("clean")
    .Does(() =>
    {
        StartProcess("dotnet", new ProcessSettings {
                Arguments = "clean --verbosity quiet"
            });
    });

Task("build")
    .Does(() =>
    {
        StartProcess("dotnet", new ProcessSettings {
                Arguments = $"build --configuration {configuration}"
            });
    });

Task("test")
    .IsDependentOn("build")
    .Does(() =>
    {
        StartProcess("dotnet", new ProcessSettings {
                Arguments = $"test --configuration {configuration}"
            });
    });

Task("pack")
    .IsDependentOn("build")
    .Does(() =>
    {
        StartProcess("dotnet", new ProcessSettings {
                Arguments = $"pack --configuration {configuration}"
            });
    });

Task("install")
    .IsDependentOn("pack")
    .Does(() =>
    {
        var tools = new[] {
            "gdmt-check-core",
            "gdmt-genpwsh",
            "gdmt-gensdk",
            "gdmt-restore"
        };

        foreach (var tool in tools)
        {
            StartProcess("dotnet", new ProcessSettings {
                    Arguments = $"tool uninstall {toolArgs} {tool}"
                });

            StartProcess("dotnet", new ProcessSettings {
                    Arguments = $"tool install --add-source {tool}/nupkg {toolInstallArgs} {tool}"
                });
        }
    });

RunTarget(target);
